@@ -12,11 +12,3 @@ setMethod("plot", "UnivariateCondDistribution",
     })
 
 
-# plot
-setMethod("plot", "DistrList", 
-    function(x,y=NULL,...){ 
-        for(i in 1:length(x)){
-            get(getOption("device"))()
-            plot(x[[i]],...)
-        }
-    })
